@@ -112,6 +112,7 @@ __all__ = (
     "ListResourceDataSyncPaginatorName",
     "MaintenanceWindowExecutionStatusType",
     "MaintenanceWindowResourceTypeType",
+    "MaintenanceWindowTaskCutoffBehaviorType",
     "MaintenanceWindowTaskTypeType",
     "NotificationEventType",
     "NotificationTypeType",
@@ -343,6 +344,7 @@ MaintenanceWindowExecutionStatusType = Literal[
     "TIMED_OUT",
 ]
 MaintenanceWindowResourceTypeType = Literal["INSTANCE", "RESOURCE_GROUP"]
+MaintenanceWindowTaskCutoffBehaviorType = Literal["CANCEL_TASK", "CONTINUE_TASK"]
 MaintenanceWindowTaskTypeType = Literal["AUTOMATION", "LAMBDA", "RUN_COMMAND", "STEP_FUNCTIONS"]
 NotificationEventType = Literal["All", "Cancelled", "Failed", "InProgress", "Success", "TimedOut"]
 NotificationTypeType = Literal["Command", "Invocation"]
